<?php

/**
 * @file
 * Includes functions related to the communication with
 * Klarna.
 */

$path = DRUPAL_ROOT . libraries_get_path('klarna', TRUE);
require_once $path . '/Klarna.php';
require_once $path . '/transport/xmlrpc-3.0.0.beta/lib/xmlrpc.inc';
require_once $path . '/transport/xmlrpc-3.0.0.beta/lib/xmlrpc_wrappers.inc';

/**
 * Helper function that initiates the Klarna object.
 *
 * @param $settings
 *  A settings array for our payment method.
 *  - estore_id: The id for our store.
 *  - secret: The shared secret for our store.
 *  - test_mode: Boolean indicating if the store is in test mode or not.
 *
 * @return
 *  A Klarna object.
 */
function commerce_klarna_init($settings) {
  // Load Klarna.
  $klarna = new Klarna();  
  
  // Configure.
  $klarna->config(
    intval($eid = $settings['estore_id']),
    mb_convert_encoding($settings['secret'], 'ISO-8859-1'),
    KlarnaCountry::SE,
    KlarnaLanguage::SV,
    KlarnaCurrency::SEK,
    $settings['test_mode'] ? Klarna::BETA : Klarna::LIVE
  );
  
  return $klarna;
}
